module GraphicsFont
	( Font
	, create, delete, select
	) where

import GraphicsTypes
import qualified Win32

----------------------------------------------------------------

newtype Font = MkFont Win32.HFONT

create :: Point -> Angle -> Bool -> Bool -> String -> IO Font
delete :: Font -> IO ()
select :: Font -> Draw Font

----------------------------------------------------------------

create (width, height) escapement bold italic family = 
 Win32.createFont (fromDimension height) (fromDimension width)
                  (round (escapement * 1800/pi))
                  0                     -- orientation
                  weight
                  italic False False    -- italic, underline, strikeout
                  Win32.aNSI_CHARSET
                  Win32.oUT_DEFAULT_PRECIS
                  Win32.cLIP_DEFAULT_PRECIS
                  Win32.dEFAULT_QUALITY
                  Win32.dEFAULT_PITCH
                  family
  >>= return . MkFont
 where
  weight | bold      = Win32.fW_BOLD
         | otherwise = Win32.fW_NORMAL

delete (MkFont f) = Win32.deleteFont f

select (MkFont f) = mkDraw (\hdc -> do
  f' <- Win32.selectFont hdc f
  return (MkFont f'))

----------------------------------------------------------------
-- The end
----------------------------------------------------------------