module GraphicsPicture
	( ellipse, shearEllipse, line
	, polyline, polygon, polyBezier
	) where

import GraphicsTypes
import qualified Win32

----------------------------------------------------------------

ellipse      :: Point -> Point          -> Draw ()
shearEllipse :: Point -> Point -> Point -> Draw ()
line         :: Point -> Point          -> Draw ()

polyline     :: [Point] -> Draw ()
polygon      :: [Point] -> Draw ()
polyBezier   :: [Point] -> Draw ()

----------------------------------------------------------------

ellipse p0 p1  = mkDraw (\ hdc -> Win32.ellipse hdc x0 y0 x1 y1)
 where 
  (x0,y0) = fromPoint p0
  (x1,y1) = fromPoint p1

shearEllipse p0 p1 p2 = mkDraw (\ hdc -> 
  Win32.transformedEllipse hdc (fromPoint p0) (fromPoint p1) (fromPoint p2))

line p0 p1 = mkDraw (\ hdc -> Win32.moveToEx hdc x0 y0 >> Win32.lineTo   hdc x1 y1)
 where 
  (x0,y0) = fromPoint p0
  (x1,y1) = fromPoint p1

polyline pts   = mkDraw (\ hdc -> Win32.polyline   hdc (map fromPoint pts))
polygon pts    = mkDraw (\ hdc -> Win32.polygon    hdc (map fromPoint pts))
polyBezier pts = mkDraw (\ hdc -> Win32.polyBezier hdc (map fromPoint pts))

----------------------------------------------------------------
