module GraphicsRegion
	( Region
	, and, or, xor, diff
	, createRectangle, createEllipse, createPolygon
	, delete, draw
	) where

import Prelude hiding (and,or)
import qualified Win32
import GraphicsTypes hiding (bracket)
import GraphicsUtilities( bracket )

----------------------------------------------------------------
-- The Interface
----------------------------------------------------------------

newtype Region = MkRegion Win32.HRGN

and       :: Region -> Region -> Region -> IO ()
or        :: Region -> Region -> Region -> IO ()
xor       :: Region -> Region -> Region -> IO ()
diff      :: Region -> Region -> Region -> IO ()
	        
draw            :: Region -> Draw ()

delete          :: Region -> IO ()
createRectangle :: Point -> Point -> IO Region
createEllipse   :: Point -> Point -> IO Region
createPolygon   :: [Point] -> IO Region

----------------------------------------------------------------
-- The Implementation
----------------------------------------------------------------

createRectangle pt0 pt1 = do
  r <- Win32.createRectRgn x0 y0 x1 y1
  return (MkRegion r)
 where
  (x0,y0) = fromPoint pt0
  (x1,y1) = fromPoint pt1

delete (MkRegion r) = Win32.deleteRegion r

createEllipse pt0 pt1 = do
  r <- Win32.createEllipticRgn x0 y0 x1 y1
  return (MkRegion r)
 where
  (x0,y0) = fromPoint pt0
  (x1,y1) = fromPoint pt1

createPolygon pts = do
  r <- Win32.createPolygonRgn (map fromPoint pts) Win32.wINDING
  return (MkRegion r)

combine :: Win32.ClippingMode -> Region -> Region -> Region -> IO ()
combine mode (MkRegion r1) (MkRegion r2) (MkRegion result) = do
  Win32.combineRgn result r1 r2 mode
  return ()

draw (MkRegion r) = mkDraw (\hdc -> Win32.paintRgn hdc r)

and  = combine Win32.rGN_AND
or   = combine Win32.rGN_OR
xor  = combine Win32.rGN_XOR
diff = combine Win32.rGN_DIFF

----------------------------------------------------------------
-- End
----------------------------------------------------------------

