module OldLib
	( module GraphicsTypes
	, clearWindow, draw
	, Picture, empty, over, overMany
	, ellipse, shearEllipse, line
	, polyline, polygon, polyBezier
	, Region, mkEmpty, mkRectangle, mkEllipse, mkPolygon
	, withRGB
	, Font,  mkFont,  withFont
	, Pen,   mkPen,   withPen
	, Brush, mkBrush, withBrush
	, Alignment, HAlign(..), VAlign(..), BkMode(..)
	, withTextColor, withTextAlignment, withBkColor, withBkMode, text
	, Style(..)
	) where

import GraphicsTypes
import GraphicsPicture

import GraphicsText   as T( Alignment, HAlign(..), VAlign(..), BkMode(..) )
import GraphicsFont   as F( Font )
import GraphicsPen    as P( Pen, Style(..) )
import GraphicsBrush  as B( Brush )
import GraphicsRegion as R( Region )
import GraphicsWindows

----------------------------------------------------------------
type Picture = Draw ()

clearWindow  :: Window -> IO ()
draw         :: Window -> Picture -> IO ()

empty        :: Picture
over         :: Picture -> Picture -> Picture
overMany     :: [Picture] -> Picture

mkEmpty         ::                     (Region -> Picture) -> Picture
mkRectangle     :: Point -> Point   -> (Region -> Picture) -> Picture
mkEllipse       :: Point -> Point   -> (Region -> Picture) -> Picture
mkPolygon       :: [Point]          -> (Region -> Picture) -> Picture

-- select a color for printing text, drawing lines, and filling areas
withRGB      :: RGB -> Picture -> Picture

mkFont   :: Point -> Angle -> Bool -> Bool -> String -> (Font  -> Picture) -> Picture
mkPen    :: Style -> Int -> RGB                      -> (Pen   -> Picture) -> Picture
mkBrush  :: RGB                                      -> (Brush -> Picture) -> Picture

withFont          :: Font      -> Picture -> Picture
withPen           :: Pen       -> Picture -> Picture
withBrush         :: Brush     -> Picture -> Picture
withTextColor     :: RGB       -> Picture -> Picture
withTextAlignment :: Alignment -> Picture -> Picture
withBkColor       :: RGB       -> Picture -> Picture
withBkMode        :: BkMode    -> Picture -> Picture

text              :: Point -> String  -> Picture
----------------------------------------------------------------
clearWindow w = setPicture w empty

draw w p = do
	oldPicture <- getPicture w
	setPicture w (p `over` oldPicture)
	redraw w
----------------------------------------------------------------
empty      = ioToDraw (return ())
p `over` q = q >> p
overMany   = foldr over empty
----------------------------------------------------------------
mkEmpty             = mkRectangle (0,0) (0,0)
mkRectangle pt0 pt1 = bracket (ioToDraw $ R.createRectangle pt0 pt1) (ioToDraw . R.delete)
mkEllipse   pt0 pt1 = bracket (ioToDraw $ R.createEllipse   pt0 pt1) (ioToDraw . R.delete)
mkPolygon   pts     = bracket (ioToDraw $ R.createPolygon   pts)     (ioToDraw . R.delete)
----------------------------------------------------------------
withRGB c p = 
  mkBrush c       $ \ brush ->
  withBrush brush $
  mkPen Solid 2 c $ \ pen ->
  withPen pen     $
  withTextColor c $
  p
----------------------------------------------------------------
mkFont size angle bold italic family = 
  bracket (ioToDraw $ F.create size angle bold italic family) 
          (ioToDraw . F.delete)
withFont f = bracket_ (F.select f) F.select
----------------------------------------------------------------
mkPen sty width c = bracket (ioToDraw $ P.create sty width c) (ioToDraw . P.delete)
withPen pen       = bracket_ (P.select pen) P.select
----------------------------------------------------------------
mkBrush rgb = bracket  (ioToDraw $ B.create rgb) (ioToDraw . B.delete)
withBrush b = bracket_ (B.select b) B.select
----------------------------------------------------------------
withTextColor     c = bracket_ (T.setTextColor c)      		        T.setTextColor
withBkColor       c = bracket_ (T.setBkColor c)        		        T.setBkColor
withBkMode     mode = bracket_ (T.setBkMode mode)       	        T.setBkMode
withTextAlignment a = bracket_ (T.setTextAlignment (T.fromAlignment a)) T.setTextAlignment
text                = T.draw
----------------------------------------------------------------

